@@ -317,7 +317,7 @@ int_norm_count <- function(data, lod_data){
 check_lod_darid <- function(lod_file, data){
   if("DataAnalysisRefID" %in% names(data) &&
      any(stringr::str_detect(data[["DataAnalysisRefID"]],
-                             "D.*0007 || D.*0008 || D.*0010 || D.*0014"))&&
+                             "D.*0007|D.*0008|D.*0010|D.*0014"))&&
      !("Version" %in% names(lod_file))&&
      any(sapply(data[["PanelDataArchiveVersion"]], function(x){
        utils::compareVersion("1.5", x)
