@@ -83,8 +83,7 @@
 #' @param reference_medians Dataset with columns "OlinkID" and "Reference_NPX".
 #' Required for reference median normalization.
 #' @param format Boolean that controls whether the normalized dataset will be
-#' formatted for input to downstream analysis. Only applicable for cross-product
-#' bridge normalization.
+#' formatted for input to downstream analysis.
 #'
 #' @return Tibble or ArrowObject with the normalized dataset.
 #'
@@ -299,7 +298,7 @@ olink_normalization <- function(df1,
       )
 
     } else if (lst_check$norm_mode == olink_norm_modes$norm_cross_product) {
-      # HT-3K normalization ----
+      # cross-product normalization ----
 
       df_norm <- norm_internal_cross_product(
         ref_df = lst_check$ref_df,
@@ -312,18 +311,6 @@ olink_normalization <- function(df1,
         not_ref_cols = lst_check$not_ref_cols
       )
 
-      if (format == TRUE) {
-        df_norm <- olink_normalization_product_format(
-          df_norm = df_norm,
-          df1 = df1,
-          df1_project_nr = df1_project_nr,
-          df2 = df2,
-          df2_project_nr = df2_project_nr,
-          prod_uniq = c(lst_check$not_ref_product, lst_check$ref_product),
-          lst_check = lst_check
-        )
-      }
-
     } else if (lst_check$norm_mode == olink_norm_modes$subset) {
       # subset normalization ----
 
@@ -341,12 +328,37 @@ olink_normalization <- function(df1,
     }
   }
 
-  # Recalculate MaxLOD
+  # inform about duplicated SampleIDs ----
+
+  if (lst_check$norm_mode %in% c(olink_norm_modes$bridge,
+                                 olink_norm_modes$norm_cross_product)) {
+    cli::cli_inform(
+      c(
+        "i" = "Output includes two sets of bridging samples.",
+        "We recommend retaining only bridge samples from the reference dataset
+          for downstream analysis."
+      )
+    )
+  }
+
+  # Recalculate MaxLOD ----
+
   df_norm <- norm_internal_update_maxlod(
     df = df_norm,
     cols = lst_check$ref_cols
   )
 
+  # format output dataset ----
+
+  if (format == TRUE) {
+
+    df_norm <- olink_normalization_format(
+      df_norm = df_norm,
+      lst_check = lst_check
+    )
+
+  }
+
   return(df_norm)
 }
 
