@@ -184,7 +184,7 @@ olink_norm_input_check <- function(df1,
       )
       norm_mode <- norm_cross_product$norm_mode
       lst_df <- norm_cross_product$lst_df
-      # bridge or 3k-HT normalization normalization
+      # bridge or E3072-HT normalization normalization
       lst_ref_samples <- list(overlapping_samples_df1, overlapping_samples_df1)
     } else if (norm_mode == olink_norm_modes$subset) {
       # subset normalization
@@ -253,6 +253,7 @@ olink_norm_input_check <- function(df1,
   )
   lst_df <- lst_df_overlap_assay$lst_df
   reference_medians <- lst_df_overlap_assay$reference_medians
+  non_overlapping_oid <- lst_df_overlap_assay$non_overlapping_oid
 
   # Check normalization approach ----
 
@@ -274,27 +275,36 @@ olink_norm_input_check <- function(df1,
 
   lst_out <- list(
     ref_df = NULL,
+    ref_original_df = NULL,
     ref_samples = NULL,
     ref_name = NULL,
     ref_cols = NULL,
     ref_product = NULL,
     not_ref_df = NULL,
+    not_ref_original_df = NULL,
     not_ref_samples = NULL,
     not_ref_name = NULL,
     not_ref_cols = NULL,
     not_ref_product = NULL,
     reference_medians = NULL,
-    norm_mode = NULL
+    norm_mode = NULL,
+    non_overlapping_oid = NULL
   )
 
   # set normalization mode
   lst_out$norm_mode <- norm_mode
 
+  # save any non-overlapping OlinkIDs
+  if (!is.null(non_overlapping_oid)) {
+    lst_out$non_overlapping_oid <- non_overlapping_oid
+  }
+
   if (norm_mode %in% olink_norm_modes$ref_median) {
     # reference median normalization
     lst_out$ref_name <- df1_project_nr
     lst_out$ref_samples <- overlapping_samples_df1
     lst_out$ref_df <- lst_df[[lst_out$ref_name]]
+    lst_out$ref_original_df <- df1
     lst_out$ref_cols <- lst_cols[[lst_out$ref_name]]
     lst_out$reference_medians <- reference_medians
   } else if (norm_mode %in% c(olink_norm_modes$subset,
@@ -302,10 +312,14 @@ olink_norm_input_check <- function(df1,
                               olink_norm_modes$norm_cross_product)) {
     # bridge or subset normalization
     if (reference_project == df1_project_nr) {
+      lst_out$ref_original_df <- df1
       lst_out$ref_name <- df1_project_nr
+      lst_out$not_ref_original_df <- df2
       lst_out$not_ref_name <- df2_project_nr
     } else {
+      lst_out$ref_original_df <- df2
       lst_out$ref_name <- df2_project_nr
+      lst_out$not_ref_original_df <- df1
       lst_out$not_ref_name <- df1_project_nr
     }
     lst_out$ref_df <- lst_df[[lst_out$ref_name]]
@@ -1118,22 +1132,22 @@ olink_norm_input_cross_product <- function(lst_df,
   # check and correct norm_mode if needed ----
 
   # check if each df comes from a different olink product:
-  # if all elements of the array contain the same product, it is simple
-  # bridge normalization. In case of 3k-3k bridging lst_product should contain
-  # only "3k" as element. For other olink products, all elements should be
+  # if all elements of the array contain the same product, it is simple a bridge
+  # normalization. In case of E3072-E3072 bridging lst_product should contain
+  # only "E3072" as element. For other olink products, all elements should be
   # NA_character.
   # If more than one products are in the vector, then it should be exclusively
-  # 3k and HT or 3k and Reveal.
-  # In any other case (e.g. 3k and NA_character) means that one df is 3k, but
-  # the other one probably T96, T48, which we do not normalize.
+  # E3072 and HT or E3072 and Reveal.
+  # In any other case (e.g. E3072 and NA_character) means that one df is E3072,
+  # but the other one probably T96, T48, which we do not normalize.
   prod_uniq <- product_ids |> unique() |> sort()
   if (length(prod_uniq) == 1L
-      && all(prod_uniq %in% c("3k", "HT", "Reveal", "other"))) {
+      && all(prod_uniq %in% c("E3072", "HT", "Reveal", "other"))) {
     norm_mode <- olink_norm_modes$bridge
-  } else if (identical(x = prod_uniq, y = c("3k", "HT"))
-             || identical(x = prod_uniq, y = c("3k", "Reveal"))
+  } else if (identical(x = prod_uniq, y = c("E3072", "HT"))
+             || identical(x = prod_uniq, y = c("E3072", "Reveal"))
              || all(prod_uniq %in% c("HT", "Reveal"))) {
-    # 3k to HT or Reveal where HT or Reveal is reference
+    # E3072 to HT or Reveal where HT or Reveal is reference
     # HT and Reveal bidirectionally
     norm_mode <- olink_norm_modes$norm_cross_product
   } else {
@@ -1206,9 +1220,7 @@ olink_norm_input_cross_product <- function(lst_df,
     l_name <- names(product_ids)[!ref_ids == "ref"]
     not_ref_product <- product_ids[ref_ids == "not_ref"] |> unname()
 
-    # Change name for 3k
-    not_ref_product <- ifelse(not_ref_product == "3k", "E3072", not_ref_product)
-
+    # Change name for not ref product
     not_ref_oid_rename <- paste0("_", not_ref_product)
 
     l_oid_rename <- paste0(lst_cols[[l_name]]$olink_id, not_ref_oid_rename)
@@ -1877,7 +1889,7 @@ olink_norm_input_clean_assays <- function(lst_df,
 #' `r cli::ansi_collapse(x = OlinkAnalyze:::olink_norm_modes, sep2 = " or ", last = " or ")`. # nolint line_length_linter
 #'
 #' @return A named list containing \var{lst_df} and \var{reference_medians}
-#' will assays shared across all datasets.
+#' with assays shared across all datasets.
 #'
 olink_norm_input_assay_overlap <- function(lst_df,
                                            reference_medians,
@@ -1936,7 +1948,10 @@ olink_norm_input_assay_overlap <- function(lst_df,
     dplyr::filter(
       .data[["L"]] != 0L
     )
-  oid_removed <- oid_combos_miss$Z |> unlist() |> unique()
+  # Keep dataset of origin for nonoverlapping assays
+  oid_removed <- oid_combos_miss |>
+    dplyr::select(all_of(c("X", "Z"))) |>
+    tibble::deframe()
 
   # remove non-shared assays and throw a warning message about it
   if (nrow(oid_combos_miss) > 0L) {
@@ -1945,23 +1960,28 @@ olink_norm_input_assay_overlap <- function(lst_df,
     lst_out$lst_df <- lapply(names(lst_df), function(l_name) {
       lst_df[[l_name]] |> # nolint return_linter
         dplyr::filter(
-          !(.data[[lst_cols[[l_name]]$olink_id]] %in% oid_removed)
+          !(.data[[lst_cols[[l_name]]$olink_id]] %in% unlist(oid_removed))
         )
     })
     names(lst_out$lst_df) <- names(lst_df)
 
+    # save any non-overlapping OlinkIDs
+    lst_out$non_overlapping_oid <- oid_removed
+
+
     # remove from reference_medians too, if available
     if (!is.null(reference_medians)) {
       lst_out$reference_medians <- reference_medians |>
         dplyr::filter(
-          !(.data[["OlinkID"]] %in% oid_removed)
+          !(.data[["OlinkID"]] %in% unlist(oid_removed))
         )
     }
     if (norm_mode == olink_norm_modes$norm_cross_product) {
       cli::cli_warn(
         c(
-          "{length(oid_removed)} assay{?s} are not shared across products.",
-          "i" = "{length(oid_removed)} assay{?s} will be removed from
+          "{length(unique(unlist(oid_removed)))} assay{?s} are not shared
+          across products.",
+          "i" = "{length(unlist(oid_removed))} assay{?s} will be removed from
         normalization."
         ),
         wrap = FALSE
@@ -1970,10 +1990,11 @@ olink_norm_input_assay_overlap <- function(lst_df,
     } else {    # warning message
       cli::cli_warn(
         c(
-          "Assay{?s} {.val {oid_removed}} not shared across input dataset(s):",
+          "Assay{?s} {.val {unique(unlist(oid_removed))}} not shared across
+          input dataset(s):",
           dplyr::pull(oid_combos_miss, .data[["M"]]),
-          "i" = "{cli::qty(oid_removed)} Assay{?s} will be removed from
-        normalization."
+          "i" = "{length(unique(unlist(oid_removed)))} Assay{?s} will be
+          removed from normalization."
         ),
         wrap = FALSE
       )
@@ -1983,9 +2004,11 @@ olink_norm_input_assay_overlap <- function(lst_df,
   } else {
 
     # if all assays shared, return original datasets
+    # If empty, set non_overlapping_oid to NULL for checks
     lst_out <- list(
       lst_df = lst_df,
-      reference_medians = reference_medians
+      reference_medians = reference_medians,
+      non_overlapping_oid = NULL
     )
 
   }
@@ -2100,7 +2123,7 @@ olink_norm_product_id <- function(lst_df,
       ) |>
       unique()
     if (all(u_panel %in% eHT_e3072_mapping$Panel_E3072)) {
-      return("3k")
+      return("E3072")
     } else if (all(u_panel == "Explore_HT")) {
       return("HT")
     } else if (all(u_panel == "Reveal")) {
@@ -2151,9 +2174,9 @@ olink_norm_reference_id <- function(lst_product,
 #'
 mapping_file_id <- function(prod_uniq) {
   # Ref mapping file
-  if (identical(x = prod_uniq, y = c("3k", "HT"))) {
+  if (identical(x = prod_uniq, y = c("E3072", "HT"))) {
     ref_map <- eHT_e3072_mapping
-  } else if (identical(x = prod_uniq, y = c("3k", "Reveal"))) {
+  } else if (identical(x = prod_uniq, y = c("E3072", "Reveal"))) {
     ref_map <- reveal_e3072_mapping
   } else if (all(prod_uniq %in% c("HT", "Reveal"))) {
     ref_map <- reveal_eht_mapping
