@@ -590,8 +590,6 @@ test_that(
   }
 )
 
-
-
 test_that(
   "olink_normalization_qs - works - fewer than 40 bridge samples",
   {
@@ -873,7 +871,6 @@ test_that(
   }
 )
 
-
 test_that(
   "olink_normalization_qs - works - HT/Reveal",
   {
@@ -947,416 +944,3 @@ test_that(
     )
   }
 )
-
-# Test olink_normalization_product_format ----
-
-test_that(
-  "olink_normalization_product_format - works - 3k-HT",
-  {
-    skip_if_not(file.exists(test_path("data", "example_3k_data.rds")))
-    skip_if_not(file.exists(test_path("data", "example_HT_data.rds")))
-
-    data_3k <- get_example_data(filename = "example_3k_data.rds")
-    data_ht <- get_example_data(filename = "example_HT_data.rds")
-
-    bridge_samples_3k_ht <- intersect(
-      x = unique(data_3k$SampleID),
-      y = unique(data_ht$SampleID)
-    ) |>
-      (\(x) x[!grepl("CONTROL", x)])()
-
-    expect_warning(
-      object = expect_message(
-        lst_check_3k_ht <- olink_norm_input_check(
-          df1 = data_3k,
-          df2 = data_ht,
-          overlapping_samples_df1 = bridge_samples_3k_ht,
-          overlapping_samples_df2 = NULL,
-          df1_project_nr = "P1",
-          df2_project_nr = "P2",
-          reference_project = "P2",
-          reference_medians = NULL
-        ),
-        regexp = "Cross-product normalization will be performed!"
-      ),
-      regexp = "2 assays are not shared across products."
-    )
-
-    # formatted data
-    expect_message(
-      object = expect_warning(
-        object = df_3k_ht_format <- olink_normalization(
-          df1 = data_3k,
-          df2 = data_ht,
-          overlapping_samples_df1 = bridge_samples_3k_ht,
-          df1_project_nr = "P1",
-          df2_project_nr = "P2",
-          reference_project = "P2",
-          format = TRUE # format data
-        ),
-        regexp = "2 assays are not shared across products."
-      ),
-      regexp = "Cross-product normalization will be performed!"
-    )
-
-    # unformatted data
-    expect_message(
-      object = expect_warning(
-        object = df_3k_ht_noformat <- olink_normalization(
-          df1 = data_3k,
-          df2 = data_ht,
-          overlapping_samples_df1 = bridge_samples_3k_ht,
-          df1_project_nr = "P1",
-          df2_project_nr = "P2",
-          reference_project = "P2"
-        ),
-        regexp = "2 assays are not shared across products."
-      ),
-      regexp = "Cross-product normalization will be performed!"
-    )
-
-    expect_no_condition(
-      object = df_3k_ht_format_fun <- olink_normalization_product_format(
-        df_norm = df_3k_ht_noformat,
-        df1 = data_ht,
-        df1_project_nr = "P2",
-        df2 = data_3k,
-        df2_project_nr = "P1",
-        lst_check = lst_check_3k_ht,
-        prod_uniq = c("3k", "HT")
-      )
-    )
-
-    ## check that function works both ways
-    expect_equal(
-      object = dim(df_3k_ht_format),
-      expected = dim(df_3k_ht_format_fun)
-    )
-
-    ## check that correct columns are removed
-    expect_false(
-      object = any(c("MedianCenteredNPX", "QSNormalizedNPX", "OlinkID_E3072")
-                   %in% colnames(df_3k_ht_format))
-    )
-
-    ## check that NotBridgeable assays get their own OlinkIDs
-    expect_equal(
-      object = df_3k_ht_format |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotBridgeable"
-        ) |>
-        dplyr::pull(
-          .data[["OlinkID"]]
-        ) |>
-        unique() |>
-        sort(),
-      expected = c("OID20054", "OID41012")
-    )
-
-    ## check that NPX is being replaced correctly
-    npx_bridging_recs <- df_3k_ht_noformat |>
-      dplyr:::mutate(
-        SampleID = paste0(.data[["SampleID"]], "_", .data[["Project"]]),
-        OlinkID =  paste0(.data[["OlinkID"]], "_", .data[["OlinkID_E3072"]])
-      ) |>
-      dplyr::select(
-        dplyr::all_of(
-          c("SampleID", "OlinkID", "Block",
-            "BridgingRecommendationOriginal" = "BridgingRecommendation",
-            "MedianCenteredNPX", "QSNormalizedNPX")
-        )
-      )
-
-    npx_assignment_check <- df_3k_ht_format |>
-      dplyr::filter(
-        !(.data[["BridgingRecommendation"]] %in% c("NotBridgeable",
-                                                   "NotOverlapping"))
-      ) |>
-      dplyr::left_join(
-        npx_bridging_recs,
-        by = c("SampleID", "OlinkID", "Block"),
-        relationship = "one-to-one"
-      ) |>
-      dplyr::filter(
-        .data[["Project"]] == "P1"
-        & !((.data[["BridgingRecommendationOriginal"]] == "MedianCentering"
-             & .data[["NPX"]] == .data[["MedianCenteredNPX"]])
-            | (.data[["BridgingRecommendationOriginal"]] == "QuantileSmoothing"
-               & .data[["NPX"]] == .data[["QSNormalizedNPX"]]))
-      )
-
-    expect_equal(
-      object = nrow(npx_assignment_check),
-      expected = 0L
-    )
-
-    ## check that the numbers of assay assignments are correct
-    expect_equal(
-      object = df_3k_ht_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotOverlapping"
-        ) |>
-        nrow(),
-      expected = 2L
-    )
-
-    expect_equal(
-      object = df_3k_ht_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotBridgeable"
-        ) |>
-        nrow(),
-      expected = 2L
-    )
-
-    expect_equal(
-      object = df_3k_ht_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "MedianCentering"
-        ) |>
-        nrow(),
-      expected = 40L
-    )
-
-    expect_equal(
-      object = df_3k_ht_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "QuantileSmoothing"
-        ) |>
-        nrow(),
-      expected = 63L
-    )
-  }
-)
-
-test_that(
-  "olink_normalization_product_format - works - 3k-Reveal",
-  {
-    skip_if_not(file.exists(test_path("data", "example_3k_data.rds")))
-    skip_if_not(file.exists(test_path("data", "example_Reveal_data.rds")))
-
-    data_3k <- get_example_data(filename = "example_3k_data.rds")
-    data_reveal <- get_example_data(filename = "example_Reveal_data.rds")
-
-    bridge_samples_3k_reveal <- intersect(
-      x = unique(data_3k$SampleID),
-      y = unique(data_reveal$SampleID)
-    ) |>
-      (\(x) x[!grepl("CONTROL", x)])() |>
-      sort() |>
-      head(35L)
-
-    expect_warning(
-      object = expect_message(
-        lst_check_3k_reveal <- olink_norm_input_check(
-          df1 = data_3k,
-          df2 = data_reveal,
-          overlapping_samples_df1 = bridge_samples_3k_reveal,
-          overlapping_samples_df2 = NULL,
-          df1_project_nr = "P1",
-          df2_project_nr = "P2",
-          reference_project = "P2",
-          reference_medians = NULL
-        ),
-        regexp = "Cross-product normalization will be performed!"
-      ),
-      regexp = "85 assays are not shared across products."
-    )
-
-    # formatted data
-    expect_warning(
-      object = expect_warning(
-        object = expect_message(
-          object = df_3k_reveal_format <- olink_normalization(
-            df1 = data_3k,
-            df2 = data_reveal,
-            overlapping_samples_df1 = bridge_samples_3k_reveal,
-            df1_project_nr = "P1",
-            df2_project_nr = "P2",
-            reference_project = "P2",
-            format = TRUE # format data
-          ),
-          regexp = "Cross-product normalization will be performed!"
-        ),
-        regexp = "85 assays are not shared across products."
-      ),
-      regexp = "There are 6 assays with fewer than 32 bridge samples for QS"
-    )
-
-    # unformatted data
-    expect_warning(
-      object = expect_warning(
-        object = expect_message(
-          object = df_3k_reveal_noformat <- olink_normalization(
-            df1 = data_3k,
-            df2 = data_reveal,
-            overlapping_samples_df1 = bridge_samples_3k_reveal,
-            df1_project_nr = "P1",
-            df2_project_nr = "P2",
-            reference_project = "P2"
-          ),
-          regexp = "Cross-product normalization will be performed!"
-        ),
-        regexp = "85 assays are not shared across products."
-      ),
-      regexp = "There are 6 assays with fewer than 32 bridge samples for QS"
-    )
-
-    expect_no_condition(
-      object = df_3k_reveal_format_fun <- olink_normalization_product_format(
-        df_norm = df_3k_reveal_noformat,
-        df1 = data_reveal,
-        df1_project_nr = "P2",
-        df2 = data_3k,
-        df2_project_nr = "P1",
-        lst_check = lst_check_3k_reveal,
-        prod_uniq = c("3k", "Reveal")
-      )
-    )
-
-    ## check that function works both ways
-    expect_equal(
-      object = dim(df_3k_reveal_format),
-      expected = dim(df_3k_reveal_format_fun)
-    )
-
-    ## check that correct columns are removed
-    expect_false(
-      object = any(c("MedianCenteredNPX", "QSNormalizedNPX", "OlinkID_E3072")
-                   %in% colnames(df_3k_reveal_format))
-    )
-
-    ## check that NotBridgeable assays get their own OlinkIDs
-    expect_equal(
-      object = df_3k_reveal_format |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotBridgeable"
-        ) |>
-        dplyr::pull(
-          .data[["OlinkID"]]
-        ) |>
-        unique() |>
-        sort(),
-      expected = c("OID20052", "OID20117", "OID20798", "OID20843", "OID20856",
-                   "OID21178", "OID21197", "OID21198", "OID21234", "OID30086",
-                   "OID30421", "OID30498", "OID31161", "OID50023", "OID50033",
-                   "OID50044", "OID50059", "OID50088", "OID50092", "OID50093",
-                   "OID50100", "OID50101", "OID50102", "OID50105", "OID50106",
-                   "OID50107")
-    )
-
-    ## check that NPX is being replaced correctly
-    npx_bridging_recs <- df_3k_reveal_noformat |>
-      dplyr:::mutate(
-        SampleID = paste0(.data[["SampleID"]], "_", .data[["Project"]]),
-        OlinkID =  paste0(.data[["OlinkID"]], "_", .data[["OlinkID_E3072"]])
-      ) |>
-      dplyr::select(
-        dplyr::all_of(
-          c("SampleID", "OlinkID", "Block",
-            "BridgingRecommendationOriginal" = "BridgingRecommendation",
-            "MedianCenteredNPX", "QSNormalizedNPX")
-        )
-      )
-
-    npx_assignment_check <- df_3k_reveal_format |>
-      dplyr::filter(
-        !(.data[["BridgingRecommendation"]] %in% c("NotBridgeable",
-                                                   "NotOverlapping"))
-      ) |>
-      dplyr::left_join(
-        npx_bridging_recs,
-        by = c("SampleID", "OlinkID", "Block"),
-        relationship = "one-to-one"
-      ) |>
-      dplyr::filter(
-        .data[["Project"]] == "P1"
-        & !((.data[["BridgingRecommendationOriginal"]] == "MedianCentering"
-             & .data[["NPX"]] == .data[["MedianCenteredNPX"]])
-            | (.data[["BridgingRecommendationOriginal"]] == "QuantileSmoothing"
-               & .data[["NPX"]] == .data[["QSNormalizedNPX"]]))
-      )
-
-    expect_equal(
-      object = nrow(npx_assignment_check),
-      expected = 0L
-    )
-
-    ## check that the numbers of assay assignments are correct
-    expect_equal(
-      object = df_3k_reveal_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotOverlapping"
-        ) |>
-        nrow(),
-      expected = 84L
-    )
-
-    expect_equal(
-      object = df_3k_reveal_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "NotBridgeable"
-        ) |>
-        nrow(),
-      expected = 26L
-    )
-
-    expect_equal(
-      object = df_3k_reveal_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "MedianCentering"
-        ) |>
-        nrow(),
-      expected = 2L
-    )
-
-    expect_equal(
-      object = df_3k_reveal_format |>
-        dplyr::distinct(
-          .data[["OlinkID"]], .data[["BridgingRecommendation"]]
-        ) |>
-        dplyr::filter(
-          .data[["BridgingRecommendation"]] == "QuantileSmoothing"
-        ) |>
-        nrow(),
-      expected = 6L
-    )
-
-    expect_true(
-      object = df_3k_reveal_noformat |>
-        dplyr::distinct(
-          .data[["Project"]], .data[["OlinkID"]]
-        ) |>
-        dplyr::group_by(
-          .data[["Project"]]
-        ) |>
-        dplyr::tally(
-          name = "n"
-        ) |>
-        dplyr::ungroup() |>
-        dplyr::pull(.data[["n"]]) |>
-        unique() == 21L
-    )
-  }
-)
